==> openshift-model-config-6.2.0-sources.jar: io/fabric8/openshift/api/model/config/v1/CustomFeatureGatesFluent.java <==
package io.fabric8.openshift.api.model.config.v1;

import java.lang.Integer;
import io.fabric8.kubernetes.api.builder.Fluent;
import java.util.ArrayList;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.String;
import java.lang.Boolean;
import java.util.Map;
import java.util.LinkedHashMap;
import java.util.function.Predicate;

 /**
  * Generated
  */
public interface CustomFeatureGatesFluent<A extends CustomFeatureGatesFluent<A>> extends Fluent<A>{
  public A addToDisabled(Integer index,String item);
  public A setToDisabled(Integer index,String item);
  public A addToDisabled(java.lang.String... items);
  public A addAllToDisabled(Collection<String> items);
  public A removeFromDisabled(java.lang.String... items);
  public A removeAllFromDisabled(Collection<String> items);
  public List<String> getDisabled();
  public String getDisabled(Integer index);
  public String getFirstDisabled();
  public String getLastDisabled();
  public String getMatchingDisabled(Predicate<String> predicate);
  public Boolean hasMatchingDisabled(Predicate<String> predicate);
  public A withDisabled(List<String> disabled);
  public A withDisabled(java.lang.String... disabled);
  public Boolean hasDisabled();
  public A addToEnabled(Integer index,String item);
  public A setToEnabled(Integer index,String item);
  public A addToEnabled(java.lang.String... items);
  public A addAllToEnabled(Collection<String> items);
  public A removeFromEnabled(java.lang.String... items);
  public A removeAllFromEnabled(Collection<String> items);
  public List<String> getEnabled();
  public String getEnabled(Integer index);
  public String getFirstEnabled();
  public String getLastEnabled();
  public String getMatchingEnabled(Predicate<String> predicate);
  public Boolean hasMatchingEnabled(Predicate<String> predicate);
  public A withEnabled(List<String> enabled);
  public A withEnabled(java.lang.String... enabled);
  public Boolean hasEnabled();
  public A addToAdditionalProperties(String key,Object value);
  public A addToAdditionalProperties(Map<String,Object> map);
  public A removeFromAdditionalProperties(String key);
  public A removeFromAdditionalProperties(Map<String,Object> map);
  public Map<String,Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties);
  public Boolean hasAdditionalProperties();
  
}

==> openshift-model-config-6.7.0-sources.jar: io/fabric8/openshift/api/model/config/v1/CustomFeatureGatesFluent.java <==
package io.fabric8.openshift.api.model.config.v1;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import com.fasterxml.jackson.annotation.JsonInclude;
import java.util.ArrayList;
import java.lang.String;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface CustomFeatureGatesFluent<A extends CustomFeatureGatesFluent<A>> extends Fluent<A>{
  public A addToDisabled(int index,String item);
  public A setToDisabled(int index,String item);
  public A addToDisabled(java.lang.String... items);
  public A addAllToDisabled(Collection<String> items);
  public A removeFromDisabled(java.lang.String... items);
  public A removeAllFromDisabled(Collection<String> items);
  public List<String> getDisabled();
  public String getDisabled(int index);
  public String getFirstDisabled();
  public String getLastDisabled();
  public String getMatchingDisabled(Predicate<String> predicate);
  public Boolean hasMatchingDisabled(Predicate<String> predicate);
  public A withDisabled(List<String> disabled);
  public A withDisabled(java.lang.String... disabled);
  public Boolean hasDisabled();
  public A addToEnabled(int index,String item);
  public A setToEnabled(int index,String item);
  public A addToEnabled(java.lang.String... items);
  public A addAllToEnabled(Collection<String> items);
  public A removeFromEnabled(java.lang.String... items);
  public A removeAllFromEnabled(Collection<String> items);
  public List<String> getEnabled();
  public String getEnabled(int index);
  public String getFirstEnabled();
  public String getLastEnabled();
  public String getMatchingEnabled(Predicate<String> predicate);
  public Boolean hasMatchingEnabled(Predicate<String> predicate);
  public A withEnabled(List<String> enabled);
  public A withEnabled(java.lang.String... enabled);
  public Boolean hasEnabled();
  public A addToAdditionalProperties(String key,Object value);
  public A addToAdditionalProperties(Map<String,Object> map);
  public A removeFromAdditionalProperties(String key);
  public A removeFromAdditionalProperties(Map<String,Object> map);
  public Map<String,Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties);
  public Boolean hasAdditionalProperties();
  
}
